==> webkit2gtk_2.14.2.orig.tar.xz: webkitgtk-2.14.2/Source/JavaScriptCore/dfg/DFGThreadData.h <==
/*
 * Copyright (C) 2014, 2015 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#ifndef DFGThreadData_h
#define DFGThreadData_h

#if ENABLE(DFG_JIT)

#include <wtf/Lock.h>
#include <wtf/Threading.h>

namespace JSC { namespace DFG {

class Safepoint;
class Worklist;

class ThreadData {
    WTF_MAKE_FAST_ALLOCATED;
public:
    ThreadData(Worklist*);
    ~ThreadData();
    
private:
    friend class Safepoint;
    friend class Worklist;
    
    Worklist* m_worklist;
    ThreadIdentifier m_identifier;
    Lock m_rightToRun;
    Safepoint* m_safepoint;
};

} } // namespace JSC::DFG

#endif // ENABLE(DFG_JIT)

#endif // DFGThreadData_h

==> webkit2gtk_2.24.4.orig.tar.xz: webkitgtk-2.24.4/Source/JavaScriptCore/dfg/DFGThreadData.h <==
/*
 * Copyright (C) 2014-2016 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#pragma once

#if ENABLE(DFG_JIT)

#include <wtf/AutomaticThread.h>
#include <wtf/Lock.h>

namespace JSC { namespace DFG {

class Safepoint;
class Worklist;

class ThreadData {
    WTF_MAKE_FAST_ALLOCATED;
public:
    ThreadData(Worklist*);
    ~ThreadData();
    
private:
    friend class Safepoint;
    friend class Worklist;
    
    Worklist* m_worklist;
    RefPtr<AutomaticThread> m_thread;
    Lock m_rightToRun;
    Safepoint* m_safepoint;
};

} } // namespace JSC::DFG

#endif // ENABLE(DFG_JIT)
